<?php

/**
 * @var Config $ccdnConf
 * @var array $customFields
 * @var array $customFieldsTable
 * @var array $categories
 * @var array $categoryBundle
 * @var array $countryBundle
 * @var array $typeBundle
 * @var array $serialStatusBundle
 * @var array $franchiseTypes
 * @var Genre[] $genres
 * @var CountryInterface[]|array $countries
 * @var PatterParser $segments
 * @var SerialStatus $serialStatus
 */

use CCDN\Helpers\Api\Response\CountryInterface;
use CCDN\Helpers\Api\Response\Field\SerialStatus;
use CCDN\Helpers\Api\Response\Genre;
use CCDN\Helpers\Enqueue;
use CCDN\Helpers\Entities\Config;
use CCDN\Helpers\Facade\Http\Url;
use CCDN\Helpers\HTML;
use CCDN\Helpers\MenuBuilder;
use CCDN\Helpers\Modules\Module\PatterParser;
use CCDN\Helpers\Settings;
use CCDN\Helpers\CCDNFunctions;

CCDNFunctions::echoHeader([
    Url::to('main') => 'Главная ' . Settings::PLUGIN_NAME,
    '' => 'Новые франшизы',
]);

global $config;

?>
	<link href="https://cdn.jsdelivr.net/npm/select2@4.0.13/dist/css/select2.min.css" rel="stylesheet">
	<link href="<?php echo Enqueue::assets('css/jquery.dataTables.min.css') ?>" rel="stylesheet">
	<link href="<?php echo Enqueue::assets('css/main.css') ?>" rel="stylesheet">
	<link href="<?php echo Enqueue::assets('css/theme-dark.css') ?>" rel="stylesheet">
<?php if ((float)$config['version_id'] < 14.0): ?>
	<link href="<?php echo Enqueue::assets('css/theme-dark-fix.css') ?>" rel="stylesheet">
<?php endif; ?>
<?php echo MenuBuilder::build() ?>
	<div class="panel panel-flat">
		<div class="panel-body">

			<div class="row">
				<div class="col-md-12">
					<h3>Новинки</h3>
				</div>
				<div class="col-md-3 my-2 mb-15">
					<label for="filter_types">Фильтр типов</label>
					<select id="filter_types" class="custom-select">
						<option selected value="">Выбрать тип франшизы...</option>
						<option value="Фильм">Фильм</option>
						<option value="Мультфильм">Мультфильм</option>
						<option value="Мультсериалы">Мультсериалы</option>
						<option value="Сериал">Сериал</option>
						<option value="ТВ шоу">ТВ шоу</option>
						<option value="Аниме-фильм">Аниме-фильм</option>
						<option value="Аниме-сериал">Аниме-сериал</option>
					</select>
				</div>
				<div class="clearfix"></div>
				<div class="col-md-12">
					<table class="table new-franchise-table table-striped table-hover">
						<thead>
						<tr>
							<th>KP id</th>
							<th>Название</th>
							<th>Реклама</th>
							<th>Тип</th>
							<th>Качество</th>
							<th>Оценка KP</th>
							<th>Оценка IMDB</th>
							<th>Год</th>
							<th title="Дата появления в базе">Дата появления</th>
							<th>Есть на сайте</th>
							<th>Действия</th>
						</tr>
						</thead>
						<tbody></tbody>
						<tfoot>
						<tr>
							<th>KP id</th>
							<th>Название</th>
							<th>Реклама</th>
							<th>Тип</th>
							<th>Качество</th>
							<th>Оценка KP</th>
							<th>Оценка IMDB</th>
							<th>Год</th>
							<th>Дата появления</th>
							<th>Есть на сайте</th>
							<th>Действия</th>
						</tr>
						</tfoot>
					</table>
				</div>
			</div>
			<hr>
			<h3>Поиск по Kinopoisk id</h3>
			<div class="row">
				<div class="col-md-4">
					<div class="input-group input-group-lg">
						<input type="text" class="form-control" id="kinopoisk_id"
						       name="kinopoisk_id" placeholder="Kinopoisk id">
						<span class="input-group-btn">
                            <button class="btn btn-green bg-teal btn-raised get-franchise-details-js"
                                    data-url="<?php echo Url::to('new-franchise-get-franchise-details') ?>"
                                    type="submit">Найти</button>
                        </span>
					</div>
				</div>
				<div class="col-md-2 overflow-hidden">
					<div class="loader loader-list-new-kinopoisk-js" style="display: none">Подождите!</div>
				</div>
				<div class="col-md-6">
					<div class="franchise-js col-md-6"
					     data-url="<?php echo Url::to('new-franchise-create-new-post-by-franchise') ?>">
					</div>
					<div class="franchise-img-js col-md-6"></div>
				</div>
			</div>
			<hr>
			<ul class="nav nav-tabs" role="tablist">
				<li role="presentation" class="active">
					<a href="#fields-to-insert" aria-controls="home" role="tab" data-toggle="tab">
						Поля для вставки
					</a>
				</li>
				<li role="presentation">
					<a href="#category-bundle" aria-controls="profile" role="tab" data-toggle="tab">
						Связки категорий и жанров франшиз
					</a>
				</li>
				<li role="presentation">
					<a href="#type-bundle" aria-controls="profile" role="tab" data-toggle="tab">
						Связки категорий и типов франшиз
					</a>
				</li>
				<li role="presentation">
					<a href="#countries-bundle" aria-controls="profile" role="tab" data-toggle="tab">
						Связки категорий и стран франшиз
					</a>
				</li>
				<li role="presentation">
					<a href="#serial_status_bundle" aria-controls="profile" role="tab" data-toggle="tab">
						Связки категорий и статусов сезонных франшиз
					</a>
				</li>
			</ul>
			<form class="needs-validation" action="<?php echo Url::to('new-franchise-save-config') ?>"
			      method="POST">
				<div class="tab-content">
					<div id="fields-to-insert" role="tabpanel" class="tab-pane fade in active">
						<h3>Поля для вставки<br>
							<small class="text-info">Некоторые поля будут использованы с основных настроек</small>
						</h3>

						<div class="row">
							<div class="form-group col-md-6">
								<input type="hidden" value="0" name="new_franchise_approve">
								<label><b>Опубликовать новость на сайте при добавлении? -</b>
									<input type="checkbox" <?php echo HTML::checked($ccdnConf->new_franchise_approve,
                                        '1') ?> value="1" name="new_franchise_approve">
								</label>
							</div>
							<div class="form-group col-md-6">
								<input type="hidden" value="0" name="new_franchise_description">
								<label><b>Добавлять описание с Kinopoisk.ru в поле "Полное описание"? -</b>
									<input type="checkbox" <?php echo HTML::checked($ccdnConf->new_franchise_description,
                                        '1') ?> value="1" name="new_franchise_description">
								</label>
							</div>
							<div class="form-group col-md-6">
								<input type="hidden" value="0" name="new_franchise_short_desc">
								<label><b>Добавлять описание с Kinopoisk.ru в поле " Краткое описание"? -</b>
									<input type="checkbox" <?php echo HTML::checked($ccdnConf->new_franchise_short_desc,
                                        '1') ?> value="1" name="new_franchise_short_desc">
								</label>
							</div>
							<div class="form-group col-md-6">
								<input type="hidden" value="0" name="new_franchise_search_year_in_cat">
								<label><b>Связывать года с категориями -</b>
									<input type="checkbox" <?php echo HTML::checked($ccdnConf->new_franchise_search_year_in_cat,
                                        '1') ?> value="1" name="new_franchise_search_year_in_cat">
								</label>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_origin_name">Поле для вставки оригинального
									названия</label>
								<select class="form-control custom-select" name="new_franchise_origin_name"
								        id="new_franchise_origin_name">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_origin_name,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_year">Поле для вставки года выхода</label>
								<select class="form-control custom-select" name="new_franchise_year"
								        id="new_franchise_year">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_year,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>

							<div class="form-group col-md-6">
								<label for="new_franchise_rating_imdb">Поле для вставки рейтига с IMDB</label>
								<select class="form-control custom-select" name="new_franchise_rating_imdb"
								        id="new_franchise_rating_imdb">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_rating_imdb,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_rating_kinopoisk">Поле для вставки рейтига с
									Kinopoisk</label>
								<select class="form-control custom-select" name="new_franchise_rating_kinopoisk"
								        id="new_franchise_rating_kinopoisk">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_rating_kinopoisk,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_rating_world_art">Поле для вставки рейтига с
									WorldArt</label>
								<select class="form-control custom-select" name="new_franchise_rating_world_art"
								        id="new_franchise_rating_world_art">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_rating_world_art,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>

							<div class="col-md-6 form-group">
								<label for="new_franchise_download_poster">Поле для загрузки постера на сервер
                                    <?php echo HTML::helpPopover('Тип поля должен быть "Загружаемое изображение"') ?>
								</label>
								<select class="form-control custom-select" name="new_franchise_download_poster"
								        id="new_franchise_download_poster">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_download_poster,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>

							<div class="col-md-6 form-group">
								<label for="new_franchise_download_poster_url">
									Поле для вставки ссылки на загруженный постер
								</label>
								<select class="form-control custom-select"
								        name="new_franchise_download_poster_url"
								        id="new_franchise_download_poster_url">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_download_poster_url,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>

							<div class="col-md-6 form-group">
								<label for="new_franchise_download_poster_url_with_domain">Поле для вставки ссылки с
									доменом на
									загруженный
									постер
								</label>
								<select class="form-control custom-select"
								        name="new_franchise_download_poster_url_with_domain"
								        id="new_franchise_download_poster_url_with_domain">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_download_poster_url_with_domain,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="clearfix"></div>
							<div class="form-group col-md-6">
								<label for="new_franchise_poster">Поле для вставки прямой ссылки на постер с сервера Collaps</label>
								<select class="form-control custom-select" name="new_franchise_poster"
								        id="new_franchise_poster">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_poster,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>

							<div class="form-group col-md-6">
								<label for="new_franchise_country">Поле для вставки стран</label>
								<select class="form-control custom-select" name="new_franchise_country"
								        id="new_franchise_country">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_country,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_director">Поле для вставки режиссеров</label>
								<select class="form-control custom-select" name="new_franchise_director"
								        id="new_franchise_director">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_director,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_actors">Поле для вставки актеров</label>
								<select class="form-control custom-select" name="new_franchise_actors"
								        id="new_franchise_actors">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_actors,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_age">Поле для вставки возраста</label>
								<select class="form-control custom-select" name="new_franchise_age"
								        id="new_franchise_age">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_age,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_time">Поле для вставки длительности видео</label>
								<select class="form-control custom-select" name="new_franchise_time"
								        id="new_franchise_time">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_time,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_premier">Поле для вставки премьеры (мир)</label>
								<select class="form-control custom-select" name="new_franchise_premier"
								        id="new_franchise_premier">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_premier,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_premier_rus">Поле для вставки премьеры (РФ)</label>
								<select class="form-control custom-select" name="new_franchise_premier_rus"
								        id="new_franchise_premier_rus">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_premier_rus,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_trailer">Поле для вставки трейлера</label>
								<select class="form-control custom-select" name="new_franchise_trailer"
								        id="new_franchise_trailer">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_trailer,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_genres">Поле для вставки жанров</label>
								<select class="form-control custom-select" name="new_franchise_genres"
								        id="new_franchise_genres">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_genres,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_slogan">Поле для вставки лозунга</label>
								<select class="form-control custom-select" name="new_franchise_slogan"
								        id="new_franchise_slogan">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_slogan,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_screenwriter">Поле для вставки сценаристов</label>
								<select class="form-control custom-select" name="new_franchise_screenwriter"
								        id="new_franchise_screenwriter">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_screenwriter,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_producer">Поле для вставки продюсеров</label>
								<select class="form-control custom-select" name="new_franchise_producer"
								        id="new_franchise_producer">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_producer,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_operator">Поле для вставки операторов</label>
								<select class="form-control custom-select" name="new_franchise_operator"
								        id="new_franchise_operator">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_operator,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_composer">Поле для вставки композиторов</label>
								<select class="form-control custom-select" name="new_franchise_composer"
								        id="new_franchise_composer">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_composer,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_design">Поле для вставки дизайнеров</label>
								<select class="form-control custom-select" name="new_franchise_design"
								        id="new_franchise_design">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_design,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_editor">Поле для вставки редакторов</label>
								<select class="form-control custom-select" name="new_franchise_editor"
								        id="new_franchise_editor">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_editor,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_actors_dubbing">Поле для вставки актеров дубляжа</label>
								<select class="form-control custom-select" name="new_franchise_actors_dubbing"
								        id="new_franchise_actors_dubbing">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_actors_dubbing,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_budget">Поле для вставки бюджета</label>
								<select class="form-control custom-select" name="new_franchise_budget"
								        id="new_franchise_budget">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_budget,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_fees_use">Поле для вставки кассовых сборов в США</label>
								<select class="form-control custom-select" name="new_franchise_fees_use"
								        id="new_franchise_fees_use">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_fees_use,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_fees_rus">Поле для вставки кассовых сборов в РФ</label>
								<select class="form-control custom-select" name="new_franchise_fees_rus"
								        id="new_franchise_fees_rus">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_fees_rus,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_fees_world">Поле для вставки кассовых сборов в мире</label>
								<select class="form-control custom-select" name="new_franchise_fees_world"
								        id="new_franchise_fees_world">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_fees_world,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_rate_mpaa">Поле для вставки рейтинга материала по шкале
									MPAA</label>
								<select class="form-control custom-select" name="new_franchise_rate_mpaa"
								        id="new_franchise_rate_mpaa">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_rate_mpaa,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_trivia">Поле для вставки “Знаете ли вы…”</label>
								<select class="form-control custom-select" name="new_franchise_trivia"
								        id="new_franchise_trivia">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_trivia,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_filed_description">Поле для вставки описания с
									Kinopoisk.ru</label>
								<select class="form-control custom-select" name="new_franchise_filed_description"
								        id="new_franchise_filed_description">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_filed_description,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_franchise_type">Поле для вставки типа франшизы</label>
								<select class="form-control custom-select" name="new_franchise_franchise_type"
								        id="new_franchise_franchise_type">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_franchise_type,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
							<div class="form-group col-md-6">
								<label for="new_franchise_name">Поле для вставки названия</label>
								<select class="form-control custom-select" name="new_franchise_name"
								        id="new_franchise_name">
									<option selected value="">Выбрать поле...</option>
                                    <?php foreach ($customFields as $customField) : ?>
										<option <?php echo HTML::selected(
                                            $ccdnConf->new_franchise_name,
                                            $customField['key']
                                        ) ?> value="<?php echo $customField['key'] ?>"><?php echo $customField['name'] ?></option>
                                    <?php endforeach; ?>
								</select>
							</div>
						</div>
					</div>
					<div id="category-bundle" role="tabpanel" class="tab-pane fade">
						<h3>Связки категорий</h3>
						<div class="row">
                            <?php foreach ($categories as $category) : ?>
								<div class="form-group col-md-6">
									<label for="category_bundle_<?php echo $category['alt_name'] ?>">Категория: <?php echo CCDNFunctions::implodeCategories($category) ?></label>
									<select class="form-control custom-select"
									        id="category_bundle_<?php echo $category['alt_name'] ?>"
									        name="category_bundle[<?php echo $category['id'] ?>]">
										<option selected value="">Выбрать...</option>
                                        <?php foreach ($genres as $genre) : ?>
											<option <?php echo HTML::selected($categoryBundle[$category['id']],
                                                $genre->getName()) ?>
													value="<?php echo $genre->getName() ?>"><?php echo $genre->getName() ?></option>
                                        <?php endforeach; ?>
									</select>
								</div>
                            <?php endforeach; ?>
						</div>
					</div>

					<div id="type-bundle" role="tabpanel" class="tab-pane fade">
						<h3>Связки категорий и типов франшиз</h3>
						<div class="row">
                            <?php foreach ($franchiseTypes as $type => $franchiseName) : ?>
								<div class="form-group col-md-6">
									<label for="type_bundle_<?php echo $type ?>">Тип
										франшизы: <?php echo $franchiseName ?></label>
									<select class="form-control custom-select" id="type_bundle_<?php echo $type ?>"
									        name="type_bundle[<?php echo $type ?>]">
										<option selected value="">Выбрать...</option>
                                        <?php foreach ($categories as $category) : ?>
											<option <?php echo HTML::selected($typeBundle[$type],
                                                $category['id']) ?>
													value="<?php echo $category['id'] ?>"><?php echo CCDNFunctions::implodeCategories($category) ?></option>
                                        <?php endforeach; ?>
									</select>
								</div>
                            <?php endforeach; ?>
						</div>
					</div>
					<div id="countries-bundle" role="tabpanel" class="tab-pane fade">
						<h3>Связки категорий и стран франшиз</h3>
						<div class="row">
                            <?php foreach ($categories as $category) : ?>

								<div class="form-group col-md-6">
									<label for="country_bundle_<?php echo $category['id'] ?>">Категория: <?php echo CCDNFunctions::implodeCategories($category) ?></label>
									<select class="form-control custom-select" id="country_bundle_<?php echo $category['id'] ?>"
									        name="country_bundle[<?php echo $category['id'] ?>]">
										<option selected value="">Выбрать...</option>
                                        <?php foreach ($countries as $country) : ?>
											<option <?php echo HTML::selected($countryBundle[$category['id']],
                                                $country->getName()) ?>
													value="<?php echo $country->getName() ?>"><?php echo $country->getName() ?></option>
                                        <?php endforeach; ?>
									</select>
								</div>
                            <?php endforeach; ?>
						</div>
					</div>
					<div id="serial_status_bundle" role="tabpanel" class="tab-pane fade">
						<h3>Связки категорий и статусов сезонных франшиз</h3>
						<p class="text-info">Эти категории будут изменяться модулем "Обновление новостей"</p>
						<div class="row">
                            <?php foreach ($categories as $category) : ?>
								<div class="form-group col-md-6">
									<label for="serial_status_bundle_<?php echo $category['id'] ?>">Категория: <?php echo CCDNFunctions::implodeCategories($category) ?></label>
									<select class="form-control custom-select" id="serial_status_bundle_<?php echo $category['id'] ?>"
									        name="serial_status_bundle[<?php echo $category['id'] ?>]">
										<option selected value="">Выбрать...</option>
                                        <?php foreach ($serialStatus->getStatusesCyrillus() as $key => $statusesCyrillus) : ?>
											<option value="<?php echo $key ?>"
                                                <?php echo HTML::selected($serialStatusBundle[$category['id']], $key) ?>
											><?php echo $statusesCyrillus ?></option>
                                        <?php endforeach; ?>
									</select>
								</div>
                            <?php endforeach; ?>
						</div>
					</div>
				</div>
				<div class="clearfix"></div>
				<ul class="nav nav-tabs col-md-12" role="tablist">
					<li role="presentation" class="active">
						<a href="#title" aria-controls="home" role="tab" data-toggle="tab">
							<i class="fa fa-text-width"></i>Заголовок
						</a>
					</li>
					<li role="presentation">
						<a href="#title2" aria-controls="profile" role="tab" data-toggle="tab">
							<i class="fa fa-font"></i>Метатег Title
						</a>
					</li>
					<li role="presentation">
						<a href="#alt" aria-controls="messages" role="tab" data-toggle="tab">
							<i class="fa fa-link"></i>ЧПУ
						</a>
					</li>
					<li role="presentation">
						<a href="#" data-toggle="modal" data-target="#tags">
							Показать теги
						</a>
					</li>
				</ul>
				<div class="tab-content col-md-12">
					<div id="title" role="tabpanel" class="tab-pane fade in active">
						<div class="table-responsive">
							<table class="table table-striped">
                                <?php echo HTML::createTableRow('Менять заголовок?', 'Если включено, модуль будет обновлять заголовок новости при выходе новых
                                серий сериалов',
                                    HTML::checkBox('new_franchise_update_title',
                                        $ccdnConf->new_franchise_update_title)) ?>

                                <?php echo HTML::createTableRow('Добавлять сезон? {season}',
                                    'Если включено, модуль будет добавлять в тайтл номер сезона',
                                    HTML::checkBox('new_franchise_add_season', $ccdnConf->new_franchise_add_season)) ?>

                                <?php echo HTML::createTableRow('Увеличить количество сезонов на?',
                                    'Модуль будет добавлять к сезону то число которое указано в поле',
                                    HTML::input('number', 'new_franchise_add_season_inc', 'new_franchise_add_season_inc',
                                        (int)$ccdnConf->new_franchise_add_season_inc)) ?>

                                <?php echo HTML::createTableRow('Формат вывода сезона',
                                    'Выберите в каком именно формате выводить сезон в тайтл',
                                    HTML::select($segments->getFormat(), 'new_franchise_season_format',
                                        $ccdnConf->new_franchise_season_format)) ?>

                                <?php echo HTML::createTableRow('Доп. поля для вставки форматированого сезона',
                                    'В это поле будет записано отформатированный сезон в соответствии с настройкиой \'Формат вывода сезона\'',
                                    HTML::select($customFieldsTable, 'new_franchise_add_season_custom_filed',
                                        $ccdnConf->new_franchise_add_season_custom_filed)) ?>

                                <?php echo HTML::createTableRow('Добавлять серию? {episode}',
                                    'Если включено, модуль будет добавлять в тайтл номер серии',
                                    HTML::checkBox('new_franchise_add_episode', $ccdnConf->new_franchise_add_episode)) ?>

                                <?php echo HTML::createTableRow('Увеличить количество серии на?',
                                    'Mодуль будет добавлять к серии то число которое указано в поле',
                                    HTML::input('number', 'new_franchise_add_episode_inc',
                                        'new_franchise_add_episode_inc',
                                        (int)$ccdnConf->new_franchise_add_episode_inc)) ?>

                                <?php echo HTML::createTableRow('Формат вывода серии',
                                    'Выберите в каком именно формате выводить серию в тайтл',
                                    HTML::select($segments->getFormat(), 'new_franchise_episode_format',
                                        $ccdnConf->new_franchise_episode_format)) ?>

                                <?php echo HTML::createTableRow('Доп. поля для вставки форматированных серии',
                                    'В это поле будет записано отформатированные серии в соответствии с настройкиой \'Формат вывода серии\'',
                                    HTML::select($customFieldsTable, 'new_franchise_add_episode_custom_filed',
                                        $ccdnConf->new_franchise_add_episode_custom_filed)) ?>

                                <?php echo HTML::createTableRow('Настройки тега {franchise_type}',
                                    'Это связка типов франшиз с вашими вариантами',
                                    HTML::input('text', 'new_franchise_franchise_type_film',
                                        'new_franchise_franchise_type_film',
                                        $ccdnConf->new_franchise_franchise_type_film, 'Для фильмов') .
                                    HTML::input('text', 'new_franchise_franchise_type_cartoon',
                                        'new_franchise_franchise_type_cartoon',
                                        $ccdnConf->new_franchise_franchise_type_cartoon, 'Для мультфильмов') .
                                    HTML::input('text', 'new_franchise_franchise_type_cartoon_series',
                                        'new_franchise_franchise_type_cartoon_series',
                                        $ccdnConf->new_franchise_franchise_type_cartoon_series, 'Для мультсериалов') .
                                    HTML::input('text', 'new_franchise_franchise_type_series',
                                        'new_franchise_franchise_type_series',
                                        $ccdnConf->new_franchise_franchise_type_series, 'Для сериалов') .
                                    HTML::input('text', 'new_franchise_franchise_type_tv_show',
                                        'new_franchise_franchise_type_tv_show',
                                        $ccdnConf->new_franchise_franchise_type_tv_show, 'Для ТВ шоу') .
                                    HTML::input('text', 'new_franchise_franchise_type_anime_film',
                                        'new_franchise_franchise_type_anime_film',
                                        $ccdnConf->new_franchise_franchise_type_anime_film, 'Для аниме-фильмов') .
                                    HTML::input('text', 'new_franchise_franchise_type_anime_series',
                                        'new_franchise_franchise_type_anime_series',
                                        $ccdnConf->new_franchise_franchise_type_anime_series, 'Для аниме-сериалов')
                                ) ?>

                                <?php echo HTML::createTableRow('Форматирование исходящего заголовка для сезонных франшиз',
                                    'Сериал {title} / {origin_name} {year} смотреть онлайн {season} сезон {episode} серия',
                                    HTML::input('text', 'new_franchise_title_pattern',
                                        'new_franchise_title_pattern',
                                        $ccdnConf->new_franchise_title_pattern)) ?>
                                <?php echo HTML::createTableRow('Форматирование исходящего
                                        заголовка для не сезонных франшиз',
                                    '{title} / {origin_name} {year} смотреть онлайн',
                                    HTML::input('text', 'new_franchise_title_pattern_not_season',
                                        'new_franchise_title_pattern_not_season',
                                        $ccdnConf->new_franchise_title_pattern_not_season)) ?>
							</table>
						</div>
					</div>
					<div id="title2" role="tabpanel" class="tab-pane fade">
						<div class="table-responsive">
							<table class="table table-striped">
                                <?php echo HTML::createTableRow('Менять метатег Title?', 'Если включено, модуль будет обновлять  метатег Title новости при выходе новых
                                серий сериалов',
                                    HTML::checkBox('new_franchise_update_title_two',
                                        $ccdnConf->new_franchise_update_title_two)) ?>

                                <?php echo HTML::createTableRow('Добавлять сезон? {season}',
                                    'Если включено, модуль будет добавлять в тайтл номер сезона',
                                    HTML::checkBox('new_franchise_add_season_two',
                                        $ccdnConf->new_franchise_add_season_two)) ?>

                                <?php echo HTML::createTableRow('Увеличить количество сезонов на?',
                                    'Модуль будет добавлять к сезону то число которое указано в поле',
                                    HTML::input('number', 'new_franchise_add_season_inc_two', 'new_franchise_add_season_inc_two',
                                        (int)$ccdnConf->new_franchise_add_season_inc_two)) ?>

                                <?php echo HTML::createTableRow('Формат вывода сезона',
                                    'Выберите в каком именно формате выводить сезон в тайтл',
                                    HTML::select($segments->getFormat(), 'new_franchise_season_format_two',
                                        $ccdnConf->new_franchise_season_format_two)) ?>

                                <?php echo HTML::createTableRow('Доп. поля для вставки форматированого сезона',
                                    'В это поле будет записано отформатированный сезон в соответствии с настройкиой \'Формат вывода сезона\'',
                                    HTML::select($customFieldsTable, 'new_franchise_add_season_custom_filed_two',
                                        $ccdnConf->new_franchise_add_season_custom_filed_two)) ?>

                                <?php echo HTML::createTableRow('Добавлять серию? {episode}',
                                    'Если включено, модуль будет добавлять в тайтл номер серии',
                                    HTML::checkBox('new_franchise_add_episode_two',
                                        $ccdnConf->new_franchise_add_episode_two)) ?>

                                <?php echo HTML::createTableRow('Увеличить количество серии на?',
                                    'Mодуль будет добавлять к серии то число которое указано в поле',
                                    HTML::input('number', 'new_franchise_add_episode_inc_two',
                                        'new_franchise_add_episode_inc_two',
                                        (int)$ccdnConf->new_franchise_add_episode_inc_two)) ?>

                                <?php echo HTML::createTableRow('Формат вывода серии',
                                    'Выберите в каком именно формате выводить серию в тайтл',
                                    HTML::select($segments->getFormat(), 'new_franchise_episode_format_two',
                                        $ccdnConf->new_franchise_episode_format_two)) ?>

                                <?php echo HTML::createTableRow('Доп. поля для вставки форматированных серии',
                                    'В это поле будет записано отформатированные серии в соответствии с настройкиой \'Формат вывода серии\'',
                                    HTML::select($customFieldsTable, 'new_franchise_add_episode_custom_filed_two',
                                        $ccdnConf->new_franchise_add_episode_custom_filed_two)) ?>

                                <?php echo HTML::createTableRow('Настройки тега {franchise_type}',
                                    'Это связка типов франшиз с вашими вариантами',
                                    HTML::input('text', 'new_franchise_franchise_type_film_two',
                                        'new_franchise_franchise_type_film_two',
                                        $ccdnConf->new_franchise_franchise_type_film_two, 'Для фильмов') .
                                    HTML::input('text', 'new_franchise_franchise_type_cartoon_two',
                                        'new_franchise_franchise_type_cartoon_two',
                                        $ccdnConf->new_franchise_franchise_type_cartoon_two, 'Для мультфильмов') .
                                    HTML::input('text', 'new_franchise_franchise_type_cartoon_series_two',
                                        'new_franchise_franchise_type_cartoon_series_two',
                                        $ccdnConf->new_franchise_franchise_type_cartoon_series_two, 'Для мультсериалов') .
                                    HTML::input('text', 'new_franchise_franchise_type_series_two',
                                        'new_franchise_franchise_type_series_two',
                                        $ccdnConf->new_franchise_franchise_type_series_two, 'Для сериалов') .
                                    HTML::input('text', 'new_franchise_franchise_type_tv_show_two',
                                        'new_franchise_franchise_type_tv_show_two',
                                        $ccdnConf->new_franchise_franchise_type_tv_show_two, 'Для ТВ шоу') .
                                    HTML::input('text', 'new_franchise_franchise_type_anime_film_two',
                                        'new_franchise_franchise_type_anime_film_two',
                                        $ccdnConf->new_franchise_franchise_type_anime_film_two, 'Для аниме-фильмов') .
                                    HTML::input('text', 'new_franchise_franchise_type_anime_series_two',
                                        'new_franchise_franchise_type_anime_series_two',
                                        $ccdnConf->new_franchise_franchise_type_anime_series_two, 'Для аниме-сериалов')
                                ) ?>

                                <?php echo HTML::createTableRow('Форматирование исходящего метатег Title для сезонных франшиз',
                                    'Сериал {title} / {origin_name} {year} смотреть онлайн {season} сезон {episode} серия ',
                                    HTML::input('text', 'new_franchise_title_two_pattern',
                                        'new_franchise_title_two_pattern',
                                        $ccdnConf->new_franchise_title_two_pattern)) ?>
                                <?php echo HTML::createTableRow('Форматирование исходящего метатег Title для не сезонных франшиз',
                                    '{title} / {origin_name} {year} смотреть онлайн',
                                    HTML::input('text', 'new_franchise_title_two_pattern_not_season',
                                        'new_franchise_title_two_pattern_not_season',
                                        $ccdnConf->new_franchise_title_two_pattern_not_season)) ?>
							</table>
						</div>
					</div>
					<div id="alt" role="tabpanel" class="tab-pane fade">
						<div class="table-responsive">
							<table class="table table-striped">
                                <?php echo HTML::createTableRow('Менять ЧПУ?', 'Если включено, модуль будет обновлять ЧПУ новости при выходе новых
                                серий сериалов',
                                    HTML::checkBox('new_franchise_update_title_alt',
                                        $ccdnConf->new_franchise_update_title_alt)) ?>

                                <?php echo HTML::createTableRow('Добавлять сезон? {season}',
                                    'Если включено, модуль будет добавлять в тайтл номер сезона',
                                    HTML::checkBox('new_franchise_add_season_alt',
                                        $ccdnConf->new_franchise_add_season_alt)) ?>

                                <?php echo HTML::createTableRow('Увеличить количество сезонов на?',
                                    'Модуль будет добавлять к сезону то число которое указано в поле',
                                    HTML::input('number', 'new_franchise_add_season_inc_alt', 'new_franchise_add_season_inc_alt',
                                        (int)$ccdnConf->new_franchise_add_season_inc_alt)) ?>

                                <?php echo HTML::createTableRow('Формат вывода сезона',
                                    'Выберите в каком именно формате выводить сезон в тайтл',
                                    HTML::select($segments->getFormatAlt(), 'new_franchise_season_format_alt',
                                        $ccdnConf->new_franchise_season_format_alt)) ?>

                                <?php echo HTML::createTableRow('Доп. поля для вставки форматированого сезона',
                                    'В это поле будет записано отформатированный сезон в соответствии с настройкиой \'Формат вывода сезона\'',
                                    HTML::select($customFieldsTable, 'new_franchise_add_season_custom_filed_alt',
                                        $ccdnConf->new_franchise_add_season_custom_filed_alt)) ?>

                                <?php echo HTML::createTableRow('Добавлять серию? {episode}',
                                    'Если включено, модуль будет добавлять в тайтл номер серии',
                                    HTML::checkBox('new_franchise_add_episode_alt',
                                        $ccdnConf->new_franchise_add_episode_alt)) ?>

                                <?php echo HTML::createTableRow('Увеличить количество серии на?',
                                    'Модуль будет добавлять к серии то число которое указано в поле',
                                    HTML::input('number', 'new_franchise_add_episode_inc_alt',
                                        'new_franchise_add_episode_inc_alt',
                                        (int)$ccdnConf->new_franchise_add_episode_inc_alt)) ?>

                                <?php echo HTML::createTableRow('Формат вывода серии',
                                    'Выберите в каком именно формате выводить серию в тайтл',
                                    HTML::select($segments->getFormatAlt(), 'new_franchise_episode_format_alt',
                                        $ccdnConf->new_franchise_episode_format_alt)) ?>

                                <?php echo HTML::createTableRow('Доп. поля для вставки форматированных серии',
                                    'В это поле будет записано отформатированные серии в соответствии с настройкиой \'Формат вывода серии\'',
                                    HTML::select($customFieldsTable, 'new_franchise_add_episode_custom_filed_alt',
                                        $ccdnConf->new_franchise_add_episode_custom_filed_alt)) ?>

                                <?php echo HTML::createTableRow('Настройки тега {franchise_type}',
                                    'Это связка типов франшиз с вашими вариантами',
                                    HTML::input('text', 'new_franchise_franchise_type_film_alt',
                                        'new_franchise_franchise_type_film_alt',
                                        $ccdnConf->new_franchise_franchise_type_film_alt, 'Для фильмов') .
                                    HTML::input('text', 'new_franchise_franchise_type_cartoon_alt',
                                        'new_franchise_franchise_type_cartoon_alt',
                                        $ccdnConf->new_franchise_franchise_type_cartoon_alt, 'Для мультфильмов') .
                                    HTML::input('text', 'new_franchise_franchise_type_cartoon_series_alt',
                                        'new_franchise_franchise_type_cartoon_series_alt',
                                        $ccdnConf->new_franchise_franchise_type_cartoon_series_alt, 'Для мультсериалов') .
                                    HTML::input('text', 'new_franchise_franchise_type_series_alt',
                                        'new_franchise_franchise_type_series_alt',
                                        $ccdnConf->new_franchise_franchise_type_series_alt, 'Для сериалов') .
                                    HTML::input('text', 'new_franchise_franchise_type_tv_show_alt',
                                        'new_franchise_franchise_type_tv_show_alt',
                                        $ccdnConf->new_franchise_franchise_type_tv_show_alt, 'Для ТВ шоу') .
                                    HTML::input('text', 'new_franchise_franchise_type_anime_film_alt',
                                        'new_franchise_franchise_type_anime_film_alt',
                                        $ccdnConf->new_franchise_franchise_type_anime_film_alt, 'Для аниме-фильмов') .
                                    HTML::input('text', 'new_franchise_franchise_type_anime_series_alt',
                                        'new_franchise_franchise_type_anime_series_alt',
                                        $ccdnConf->new_franchise_franchise_type_anime_series_alt, 'Для аниме-сериалов')
                                ) ?>

                                <?php echo HTML::createTableRow('Форматирование исходящего ЧПУ для сезонных франшиз',
                                    'serial-{title}-{origin_name}-{year}-smotret-onlayn-{season}-sezon-{episode}-seriya',
                                    HTML::input('text', 'new_franchise_title_alt_pattern', 'patter',
                                        $ccdnConf->new_franchise_title_alt_pattern)) ?>
                                <?php echo HTML::createTableRow('Форматирование исходящего ЧПУ для не сезонных франшиз',
                                    '{title}-{origin_name}-{year}-smotret-onlayn',
                                    HTML::input('text', 'new_franchise_title_alt_pattern_not_season',
                                        'new_franchise_title_alt_pattern_not_season',
                                        $ccdnConf->new_franchise_title_alt_pattern_not_season)) ?>
							</table>
						</div>
					</div>
				</div>
				<div class="clearfix"></div>
				<div class="form-group">
					<button class="btn btn-green bg-teal btn-raised" type="submit">Сохранить настройки</button>
				</div>
			</form>
		</div>
	</div>

	<div class="modal fade" id="myModal" tabindex="-1" role="dialog" aria-labelledby="myModalLabel">
		<div class="modal-dialog modal-lg" role="document">
			<div class="modal-content">
				<div class="modal-header ui-dialog-titlebar">
					<button type="button" class="close ui-dialog-titlebar-close ui-corner-all" data-dismiss="modal" aria-label="Close"><span
								aria-hidden="true">&times;</span></button>
					<span class="modal-title ui-dialog-title" id="myModalLabel"></span>
				</div>
				<div class="modal-body">
					<iframe src="" width="100%" height="480" allowfullscreen="" webkitallowfullscreen=""
					        mozallowfullscreen="" oallowfullscreen="" msallowfullscreen="" style="border: 0;"></iframe>
				</div>
				<div class="modal-footer">
					<button type="button" class="btn btn-gray bg-slate-600 btn-raised" data-dismiss="modal">Закрыть</button>
				</div>
			</div>
		</div>
	</div>

	<div class="modal fade" id="tags" tabindex="-1" role="dialog" aria-labelledby="myModalLabel">
		<div class="modal-dialog modal-lg" role="document">
			<div class="modal-content">
				<div class="modal-header ui-dialog-titlebar">
					<button type="button" class="close ui-dialog-titlebar-close ui-corner-all" data-dismiss="modal" aria-label="Close"><span
								aria-hidden="true">&times;</span></button>
					<span class="modal-title ui-dialog-title" id="myModalLabel">Доступние теги для вставки (все данные берутся с API)</span>
				</div>
				<div class="modal-body">
					<p><b>{title}</b> - название франшизы</p>
					<p><b>{origin_name}</b> - оригинальное название франшизы</p>
					<p><b>{season}</b> - номер сезона</p>
					<p><b>{episode}</b> - номер эпизода</p>
					<p><b>{year}</b> - год выхода франшизы</p>
					<p><b>{franchise_type}</b> - связка типов франшиз с вашими вариантами</p>
					<p><b>[multi-season]</b>много<b>[else]</b>один<b>[/multi-season]</b><br><b>[multi-season]</b>много<b>[/multi-season]</b> -
						проверка на многосезонные франшизы (доступно только в полях форматирования для сезонных франшиз)</p>
				</div>
				<div class="modal-footer">
					<button type="button" class="btn btn-gray bg-slate-600 btn-raised" data-dismiss="modal">Закрыть</button>
				</div>
			</div>
		</div>
	</div>

	<script src="https://cdn.jsdelivr.net/npm/select2@4.0.13/dist/js/select2.min.js"></script>
	<script src="<?php echo Enqueue::assets('js/jquery.dataTables.min.js') ?>"></script>
	<script src="https://cdn.datatables.net/plug-ins/1.10.21/pagination/input.js"></script>
	<script src="<?php echo Enqueue::assets('js/new-franchise.js') ?>"></script>
	<script>
		$(document).ready(function () {
			$('.new-franchise-table').DataTable({
				order: [[0, "desc"]],
				processing: true,
				pagingType: "input",
				ajax: "<?php echo Url::to('new-franchise-list') ?>",
				columns: [
					{
						data: "kinopoisk_id",
						className: "text-center",
						render: function (data, type, full) {
							var a = '';

							if (data !== null) {
								a = '<a target="_blank" href="https://www.kinopoisk.ru/film/' + data + '/">' + data + '</a>'
							}
							return a;
						}
					},
					{
						data: "name",
						render: function (data, type, full) {
							if (data.length > 20) {
								data = data.substring(0, 20) + '...'
							}

							if (full.has_in_db) {
								var aButton = document.createElement('a');
								aButton.href = full.post_url;
								aButton.textContent = data;
								data = aButton.outerHTML;
							}

							return data;
						}
					},
					{
						data: "ads",
						className: "text-center",
						render: function (data, type, full) {
							if (!data) {
								return '<i class="text-success fa fa-minus"></i>';
							}
							return '<i class="text-danger fa fa-plus"></i>';
						}
					},
					{data: "type"},
					{data: "quality"},
					{
						data: "kinopoisk",
						className: "text-center",
					},
					{
						data: "imdb",
						className: "text-center",
					},
					{
						data: "year",
						className: "text-center",
					},
					{
						data: "activate_time",
						className: "text-center",
					},
					{
						data: "has_in_db",
						className: "text-center",
						render: function (data, type, full) {
							if (!data) {
								return '<i class="text-danger fa fa-times-circle-o"></i>';
							}
							return '<i class="text-success fa fa-check-circle"></i>';
						}
					},
					{
						data: null,
						render: function (data, type, full) {

							var btn = document.createElement('button');
							btn.type = 'button';
							btn.dataset.toggle = 'modal';
							btn.dataset.target = '#myModal';
							btn.innerHTML = '<i class="fa fa-eye" aria-hidden="true"></i>';
							btn.classList = 'btn-link btn-sm';
							btn.title = 'Просмотр';
							btn.dataset.iframe_url = full.iframe_url;
							btn.dataset.video_name = full.name;

							var html = '';
							html += btn.outerHTML;
							if (!full.has_in_db) {
								var button = document.createElement('button');
								var loadDiv = document.createElement('div');

								loadDiv.classList = 'loader loader-create-franchise loader-create-franchise-js';
								loadDiv.textContent = 'Подождите!';
								loadDiv.style.display = 'none';

								button.classList = 'btn-link btn-sm create-new-post-by-franchise-js overflow-hidden';
								button.innerHTML = '<i class="fa fa-plus" aria-hidden="true"></i>' + loadDiv.outerHTML;
								button.type = 'button';
								button.title = 'Добавить';
								button.dataset.url = "<?php echo Url::to('new-franchise-create-new-post-by-franchise') ?>";
								button.dataset.collaps_id = full.id;
								html += button.outerHTML;
							}

							return html;
						}
					},
				],
				language: {
					lengthMenu: "Показывать _MENU_ записей на странице",
					zeroRecords: "Ничего не найдено - извините",
					info: "Отображение страницы _PAGE_ из _PAGES_",
					infoEmpty: "Нет доступных записей",
					infoFiltered: "(отфильтровано по итоговым записям _MAX_)",
					search: "Поиск:",
					processing: "Загрузка...",
					paginate: {
						info: "Страница _INPUT_ из _TOTAL_",
						first: "<i class=\"fa fa-fast-backward\" aria-hidden=\"true\"></i>",
						last: "<i class=\"fa fa-fast-forward\" aria-hidden=\"true\"></i>",
						next: "<i class=\"fa fa-step-forward\" aria-hidden=\"true\"></i></i>",
						previous: "<i class=\"fa fa-step-backward\" aria-hidden=\"true\"></i>"
					},
				},
			});


			$('.custom-select').select2({
				width: '100%',
				placeholder: 'Выбрать...',
				allowClear: true,
				multiple: false,
			});
		});
	</script>
<?php
echofooter();
